datastructuretools.ImmutableDictionary
======================================

.. inheritance-diagram:: abjad.tools.datastructuretools.ImmutableDictionary.ImmutableDictionary.ImmutableDictionary
   :private-bases:

.. autoclass:: abjad.tools.datastructuretools.ImmutableDictionary.ImmutableDictionary.ImmutableDictionary

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.datastructuretools.ImmutableDictionary.ImmutableDictionary.ImmutableDictionary.storage_format

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

Methods
-------

.. automethod:: abjad.tools.datastructuretools.ImmutableDictionary.ImmutableDictionary.ImmutableDictionary.clear

    Inherited from :py:class:`__builtin__.dict`

.. automethod:: abjad.tools.datastructuretools.ImmutableDictionary.ImmutableDictionary.ImmutableDictionary.copy

    Inherited from :py:class:`__builtin__.dict`

.. automethod:: abjad.tools.datastructuretools.ImmutableDictionary.ImmutableDictionary.ImmutableDictionary.get

    Inherited from :py:class:`__builtin__.dict`

.. automethod:: abjad.tools.datastructuretools.ImmutableDictionary.ImmutableDictionary.ImmutableDictionary.has_key

    Inherited from :py:class:`__builtin__.dict`

.. automethod:: abjad.tools.datastructuretools.ImmutableDictionary.ImmutableDictionary.ImmutableDictionary.items

    Inherited from :py:class:`__builtin__.dict`

.. automethod:: abjad.tools.datastructuretools.ImmutableDictionary.ImmutableDictionary.ImmutableDictionary.iteritems

    Inherited from :py:class:`__builtin__.dict`

.. automethod:: abjad.tools.datastructuretools.ImmutableDictionary.ImmutableDictionary.ImmutableDictionary.iterkeys

    Inherited from :py:class:`__builtin__.dict`

.. automethod:: abjad.tools.datastructuretools.ImmutableDictionary.ImmutableDictionary.ImmutableDictionary.itervalues

    Inherited from :py:class:`__builtin__.dict`

.. automethod:: abjad.tools.datastructuretools.ImmutableDictionary.ImmutableDictionary.ImmutableDictionary.keys

    Inherited from :py:class:`__builtin__.dict`

.. automethod:: abjad.tools.datastructuretools.ImmutableDictionary.ImmutableDictionary.ImmutableDictionary.pop

    Inherited from :py:class:`__builtin__.dict`

.. automethod:: abjad.tools.datastructuretools.ImmutableDictionary.ImmutableDictionary.ImmutableDictionary.popitem

    Inherited from :py:class:`__builtin__.dict`

.. automethod:: abjad.tools.datastructuretools.ImmutableDictionary.ImmutableDictionary.ImmutableDictionary.setdefault

    Inherited from :py:class:`__builtin__.dict`

.. automethod:: abjad.tools.datastructuretools.ImmutableDictionary.ImmutableDictionary.ImmutableDictionary.update

    Inherited from :py:class:`__builtin__.dict`

.. automethod:: abjad.tools.datastructuretools.ImmutableDictionary.ImmutableDictionary.ImmutableDictionary.values

    Inherited from :py:class:`__builtin__.dict`

.. automethod:: abjad.tools.datastructuretools.ImmutableDictionary.ImmutableDictionary.ImmutableDictionary.viewitems

    Inherited from :py:class:`__builtin__.dict`

.. automethod:: abjad.tools.datastructuretools.ImmutableDictionary.ImmutableDictionary.ImmutableDictionary.viewkeys

    Inherited from :py:class:`__builtin__.dict`

.. automethod:: abjad.tools.datastructuretools.ImmutableDictionary.ImmutableDictionary.ImmutableDictionary.viewvalues

    Inherited from :py:class:`__builtin__.dict`

Special Methods
---------------

.. automethod:: abjad.tools.datastructuretools.ImmutableDictionary.ImmutableDictionary.ImmutableDictionary.__cmp__

    Inherited from :py:class:`__builtin__.dict`

.. automethod:: abjad.tools.datastructuretools.ImmutableDictionary.ImmutableDictionary.ImmutableDictionary.__contains__

    Inherited from :py:class:`__builtin__.dict`

.. automethod:: abjad.tools.datastructuretools.ImmutableDictionary.ImmutableDictionary.ImmutableDictionary.__delitem__

.. automethod:: abjad.tools.datastructuretools.ImmutableDictionary.ImmutableDictionary.ImmutableDictionary.__eq__

    Inherited from :py:class:`__builtin__.dict`

.. automethod:: abjad.tools.datastructuretools.ImmutableDictionary.ImmutableDictionary.ImmutableDictionary.__ge__

    Inherited from :py:class:`__builtin__.dict`

.. automethod:: abjad.tools.datastructuretools.ImmutableDictionary.ImmutableDictionary.ImmutableDictionary.__getitem__

    Inherited from :py:class:`__builtin__.dict`

.. automethod:: abjad.tools.datastructuretools.ImmutableDictionary.ImmutableDictionary.ImmutableDictionary.__gt__

    Inherited from :py:class:`__builtin__.dict`

.. automethod:: abjad.tools.datastructuretools.ImmutableDictionary.ImmutableDictionary.ImmutableDictionary.__iter__

    Inherited from :py:class:`__builtin__.dict`

.. automethod:: abjad.tools.datastructuretools.ImmutableDictionary.ImmutableDictionary.ImmutableDictionary.__le__

    Inherited from :py:class:`__builtin__.dict`

.. automethod:: abjad.tools.datastructuretools.ImmutableDictionary.ImmutableDictionary.ImmutableDictionary.__len__

    Inherited from :py:class:`__builtin__.dict`

.. automethod:: abjad.tools.datastructuretools.ImmutableDictionary.ImmutableDictionary.ImmutableDictionary.__lt__

    Inherited from :py:class:`__builtin__.dict`

.. automethod:: abjad.tools.datastructuretools.ImmutableDictionary.ImmutableDictionary.ImmutableDictionary.__ne__

    Inherited from :py:class:`__builtin__.dict`

.. automethod:: abjad.tools.datastructuretools.ImmutableDictionary.ImmutableDictionary.ImmutableDictionary.__repr__

    Inherited from :py:class:`__builtin__.dict`

.. automethod:: abjad.tools.datastructuretools.ImmutableDictionary.ImmutableDictionary.ImmutableDictionary.__setitem__
